@@ -165,14 +165,12 @@ theme_thumbnail_generate (GnomeThemeMetaInfo *info, AppearanceData *data)
 }
 
 static void
-theme_changed_on_disk_cb (GnomeThemeType       type,
-			  gpointer             theme,
-			  GnomeThemeChangeType change_type,
-			  GnomeThemeElement    element,
+theme_changed_on_disk_cb (GnomeThemeCommonInfo *theme,
+			  GnomeThemeChangeType  change_type,
 			  AppearanceData       *data)
 {
-  if (type == GNOME_THEME_TYPE_METATHEME) {
-    GnomeThemeMetaInfo *meta = theme;
+  if (theme->type == GNOME_THEME_TYPE_METATHEME) {
+    GnomeThemeMetaInfo *meta = (GnomeThemeMetaInfo *) theme;
 
     if (change_type == GNOME_THEME_CHANGE_CREATED) {
       gtk_list_store_insert_with_values (data->theme_store, NULL, 0,
@@ -218,47 +216,43 @@ is_locked_down (GConfClient *client)
   return gconf_client_get_bool (client, LOCKDOWN_KEY, NULL);
 }
 
-static void
-theme_load_from_gconf (GConfClient *client, GnomeThemeMetaInfo *theme)
+static GnomeThemeMetaInfo *
+theme_load_from_gconf (GConfClient *client)
 {
+  GnomeThemeMetaInfo *theme;
   gchar *scheme;
 
-  g_free (theme->gtk_theme_name);
+  theme = gnome_theme_meta_info_new ();
+
   theme->gtk_theme_name = gconf_client_get_string (client, GTK_THEME_KEY, NULL);
   if (theme->gtk_theme_name == NULL)
     theme->gtk_theme_name = g_strdup ("Clearlooks");
 
-  g_free (theme->gtk_color_scheme);
   scheme = gconf_client_get_string (client, COLOR_SCHEME_KEY, NULL);
-
   if (scheme == NULL || !strcmp (scheme, "")) {
     g_free (scheme);
     scheme = gtkrc_get_color_scheme_for_theme (theme->gtk_theme_name);
   }
   theme->gtk_color_scheme = scheme;
 
-  g_free (theme->metacity_theme_name);
   theme->metacity_theme_name = gconf_client_get_string (client, METACITY_THEME_KEY, NULL);
   if (theme->metacity_theme_name == NULL)
     theme->metacity_theme_name = g_strdup ("Clearlooks");
 
-  g_free (theme->icon_theme_name);
   theme->icon_theme_name = gconf_client_get_string (client, ICON_THEME_KEY, NULL);
   if (theme->icon_theme_name == NULL)
     theme->icon_theme_name = g_strdup ("gnome");
 
-  g_free (theme->cursor_theme_name);
-#ifdef HAVE_XCURSOR
   theme->cursor_theme_name = gconf_client_get_string (client, CURSOR_THEME_KEY, NULL);
+#ifdef HAVE_XCURSOR
   theme->cursor_size = gconf_client_get_int (client, CURSOR_SIZE_KEY, NULL);
-#else
-  theme->cursor_theme_name = gconf_client_get_string (client, CURSOR_FONT_KEY, NULL);
 #endif
   if (theme->cursor_theme_name == NULL)
     theme->cursor_theme_name = g_strdup ("default");
 
-  g_free (theme->application_font);
   theme->application_font = gconf_client_get_string (client, APPLICATION_FONT_KEY, NULL);
+
+  return theme;
 }
 
 static gchar *
@@ -343,6 +337,9 @@ theme_is_equal (const GnomeThemeMetaInfo *a, const GnomeThemeMetaInfo *b)
       strcmp (a->cursor_theme_name, b->cursor_theme_name))
     return FALSE;
 
+  if (a->cursor_size != b->cursor_size)
+    return FALSE;
+
   a_set = a->gtk_color_scheme && strcmp (a->gtk_color_scheme, "");
   b_set = b->gtk_color_scheme && strcmp (b->gtk_color_scheme, "");
   if ((a_set != b_set) ||
@@ -596,7 +593,7 @@ theme_selection_changed_cb (GtkWidget *icon_view, AppearanceData *data)
   }
 
   gtk_widget_set_sensitive (glade_xml_get_widget (data->xml, "theme_delete"),
-			    gnome_theme_is_writable (theme, GNOME_THEME_TYPE_METATHEME));
+			    theme_is_writable (theme));
   gtk_widget_set_sensitive (glade_xml_get_widget (data->xml, "theme_save"), is_custom);
 }
 
@@ -670,8 +667,7 @@ theme_details_changed_cb (AppearanceData *data)
   gboolean done = FALSE;
 
   /* load new state from gconf */
-  gconf_theme = gnome_theme_meta_info_new ();
-  theme_load_from_gconf (data->client, gconf_theme);
+  gconf_theme = theme_load_from_gconf (data->client);
 
   /* check if it's our currently selected theme */
   icon_view = GTK_ICON_VIEW (glade_xml_get_widget (data->xml, "theme_list"));
@@ -834,9 +830,9 @@ themes_init (AppearanceData *data)
   theme_list = gnome_theme_meta_info_find_all ();
   gnome_theme_info_register_theme_change ((ThemeChangedCallback) theme_changed_on_disk_cb, data);
 
+  data->theme_custom = theme_load_from_gconf (data->client);
   data->theme_custom->name = g_strdup (CUSTOM_THEME_NAME);
   data->theme_custom->readable_name = g_strdup_printf ("<i>%s</i>", _("Custom"));
-  theme_load_from_gconf (data->client, data->theme_custom);
 
   for (l = theme_list; l; l = l->next) {
     GnomeThemeMetaInfo *info = l->data;
@@ -926,6 +922,10 @@ themes_init (AppearanceData *data)
   gconf_client_add_dir (data->client, "/apps/metacity/general", GCONF_CLIENT_PRELOAD_NONE, NULL);
   gconf_client_add_dir (data->client, "/desktop/gnome/interface", GCONF_CLIENT_PRELOAD_NONE, NULL);
   gconf_client_notify_add (data->client, METACITY_THEME_KEY, (GConfClientNotifyFunc) theme_gconf_changed, data, NULL, NULL);
+  gconf_client_notify_add (data->client, CURSOR_THEME_KEY, (GConfClientNotifyFunc) theme_gconf_changed, data, NULL, NULL);
+#ifdef HAVE_XCURSOR
+  gconf_client_notify_add (data->client, CURSOR_SIZE_KEY, (GConfClientNotifyFunc) theme_gconf_changed, data, NULL, NULL);
+#endif
   gconf_client_notify_add (data->client, BACKGROUND_KEY, (GConfClientNotifyFunc) background_or_font_changed, data, NULL, NULL);
   gconf_client_notify_add (data->client, APPLICATION_FONT_KEY, (GConfClientNotifyFunc) background_or_font_changed, data, NULL, NULL);
   gconf_client_notify_add (data->client, DESKTOP_FONT_KEY, (GConfClientNotifyFunc) background_or_font_changed, data, NULL, NULL);
