@@ -30,10 +30,10 @@
 #include <gnome.h>
 #include <glade/glade.h>
 
-#include "capplet-util.h"
-
+#include <libgnomekbd/gkbd-keyboard-drawing.h>
 #include <libgnomekbd/gkbd-util.h>
 
+#include "capplet-util.h"
 #include "gnome-keyboard-properties-xkb.h"
 
 #define GROUP_SWITCHERS_GROUP "grp"
@@ -113,6 +113,7 @@ xkb_layout_chooser_enable_disable_buttons (GladeXML * chooser_dialog)
 	gtk_dialog_set_response_sensitive (GTK_DIALOG
 					   (CWID ("xkb_layout_chooser")),
 					   GTK_RESPONSE_OK, enable_ok);
+	gtk_widget_set_sensitive (CWID ("btnPrint"), enable_ok);
 }
 
 static void
@@ -354,6 +355,22 @@ xkl_layout_chooser_add_default_switcher_if_necessary (GSList *
 	}
 }
 
+static void
+xkb_layout_chooser_print (GladeXML * chooser_dialog)
+{
+	GtkWidget *chooser = CWID ("xkb_layout_chooser");
+	GtkWidget *kbdraw =
+	    GTK_WIDGET (g_object_get_data (G_OBJECT (chooser), "kbdraw"));
+	const char *id =
+	    xkb_layout_chooser_get_selected_id (chooser_dialog);
+	char *descr = xkb_layout_description_utf8 (id);
+	gkbd_keyboard_drawing_print (GKBD_KEYBOARD_DRAWING (kbdraw),
+				     GTK_WINDOW (CWID
+						 ("xkb_layout_chooser")),
+				     descr);
+	g_free (descr);
+}
+
 static void
 xkb_layout_chooser_response (GtkDialog * dialog,
 			     gint response, GladeXML * chooser_dialog)
@@ -379,6 +396,11 @@ xkb_layout_chooser_response (GtkDialog * dialog,
 
 			clear_xkb_elements_list (layouts_list);
 		}
+	} else if (response == gtk_dialog_get_response_for_widget
+		   (dialog, CWID ("btnPrint"))) {
+		xkb_layout_chooser_print (chooser_dialog);
+		g_signal_stop_emission_by_name (dialog, "response");
+		return;
 	}
 
 	gtk_window_get_position (GTK_WINDOW (dialog), &rect.x, &rect.y);
@@ -387,7 +409,6 @@ xkb_layout_chooser_response (GtkDialog * dialog,
 	gkbd_preview_save_position (&rect);
 }
 
-
 void
 xkb_layout_choose (GladeXML * dialog)
 {
@@ -413,10 +434,15 @@ xkb_layout_choose (GladeXML * dialog)
 		gtk_container_add (GTK_CONTAINER (CWID ("previewFrame")),
 				   kbdraw);
 		gtk_widget_show_all (kbdraw);
+		gtk_button_box_set_child_secondary (GTK_BUTTON_BOX
+						    (CWID ("hbtnBox")),
+						    CWID ("btnPrint"),
+						    TRUE);
 	} else
 #endif
 	{
 		gtk_widget_hide_all (CWID ("vboxPreview"));
+		gtk_widget_hide (CWID ("btnPrint"));
 	}
 
 	g_signal_connect (G_OBJECT (chooser),
